[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](../../CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/essnmx.svg)](https://pypi.python.org/pypi/essnmx)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/essnmx/badges/version.svg)](https://anaconda.org/conda-forge/essnmx)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](../../LICENSE)

# ESSnmx

## About

Data reduction for NMX at the European Spallation Source.

## Installation

```sh
python -m pip install essnmx
```
